Module ts

Module ts 

High-level support for the TS event server

Structs

Event
The data field usually contains a serialized Protobuf structure.
TsConnectInfo
Connection information required to open a session with the TS server
TsConnectResponse
Response to a connection from the TS server
TsEventAcceptor
Accept TsEventSocket connections
TsEventSocket
Async socket used to stream Events with the TS service

Enums

AgentIdStatus
Whether the server expects the client to keep its Agent ID or be assigned a new one
EventId
Tries to provide meaningful names for some well-known Events.
TsPacketKind
Besides transporting events, the TS sub-protocol has handshake packets and an ACK mechanism