High-level support for the TS event server
Structs
- Event
- The
datafield usually contains a serialized Protobuf structure. - TsConnect
Info - Connection information required to open a session with the TS server
- TsConnect
Response - Response to a connection from the TS server
- TsEvent
Acceptor - Accept
TsEventSocketconnections - TsEvent
Socket - Async socket used to stream
Events with the TS service
Enums
- Agent
IdStatus - Whether the server expects the client to keep its Agent ID or be assigned a new one
- EventId
- Tries to provide meaningful names for some well-known
Events. - TsPacket
Kind - Besides transporting events, the TS sub-protocol has handshake packets and an ACK mechanism